import { Component, Input, ElementRef, Inject, OnInit, OnDestroy, OnChanges, SimpleChanges } from '@angular/core';

@Component({
    selector: 'spread-sheets',
    template: `
              <div style="width:100%;height:100%;">
              </div>
            `
})

export class SpreadSheetsComponent implements OnInit, OnDestroy, OnChanges {
    elRef:ElementRef;
    workbook:GC.Spread.Sheets.Workbook;

    @Input() options: any;

    constructor(@Inject(ElementRef) elRef:ElementRef) {
        this.elRef = elRef;
    }

    ngOnDestroy() {
        this.workbook.destroy();
    }

    ngOnInit() {
        var dom = <HTMLElement>this.elRef.nativeElement;
        if (!this.workbook) {
            var hostElement = dom.getElementsByTagName('div')[0];
            this.workbook = new GC.Spread.Sheets.Workbook(hostElement, this.options || {});
            this.applySheetsOptions(this.options);
        }
    }

    applySheetsOptions(options) {
        var sheets = this.workbook.sheets;
        var sheetOptions = options.sheets;
        if (sheetOptions) {
            for (var i = 0; i < sheetOptions.length; i++) {
                var sheetOption = sheetOptions[i];
                if (!sheets[i] || !sheetOption) break;
                this.applySheetOption(sheets[i], sheetOption);
            }
        }
    }

    applySheetOption(sheet, sheetOption) {
        for (var option in sheetOption) {
            if (option === 'name') {
                sheet.name(sheetOption.name);
            } else if (option === 'dataSource') {
                sheet.setDataSource(sheetOption.dataSource);
            } else if (option === 'columns') {
                var columns = sheetOption.columns;
                columns.forEach((column, index) => {
                    if (column.dataField) {
                        sheet.bindColumn(index, {
                            name: column.dataField,
                            displayName: column.headerText,
                            formatter: column.formatter
                        });
                    }

                    if (!isNaN(column.width)) {
                        sheet.setColumnWidth(index, column.width);
                    }
                });
                sheet.setColumnCount(columns.length);
            } else {
                sheet.options[option] = sheetOption[option];
            }
        }                
    }

    ngOnChanges(changes: SimpleChanges) {
        if (!this.workbook) return;

        var options = changes['options'] && changes['options'].currentValue;
        if (options) {
            this.workbook.clearSheets();

            // apply workbook options
            for (var option in options) {
                if (option === 'sheets') {
                    continue;
                } else if (option === 'sheetCount') {
                    this.workbook.setSheetCount(options[option]);
                } else {
                    this.workbook.options[option] = options[option];
                }
            }

            // apply sheets options
            if (options['sheets']) {
                this.applySheetsOptions(options['sheets']);
            }
        }
    }
}
