import { Component, Input, ViewChild, AfterViewInit } from '@angular/core';
import {SpreadSheetsComponent} from "./spread/spreadSheets.component";

@Component({
    selector: 'my-app',
    template: `
    <div style="width:800px; height:400px; border:1px solid black;">
        <spread-sheets #ss [options] = "options"></spread-sheets>      
    </div>
    <h3>Events</h3>
    <div>{{message}}<div>
    `
})

export class AppComponent implements AfterViewInit {
    @ViewChild('ss') spread: SpreadSheetsComponent;

    public message: string;
    @Input() options: any;        

    constructor() {
        var data = [];
        var countries = ["US", "Germany", "UK", "Japan", "Italy"];
        var products = ["Widget", "Gadget", "Doohickey"];
        var count = 50;
        for (var i = 0; i < count; i++) {
            var item = {
                country: countries[Math.floor(Math.random() * countries.length)],
                product: products[Math.floor(Math.random() * products.length)],
                amount: 1000 + Math.random() * 10000,
                date: new Date()
            };
            data.push(item);
        }

        this.options = {
            backColor: "white",
            grayAreaBackColor: "lightgray",
            sheetCount: 2,
            sheets: [{
                name: "Sales",
                dataSource: data,
                columns: [
                    { dataField: "date", headerText: "Date", formatter:"dd/mm/yyyy", width: 100, },
                    { dataField: "country", headerText: "Country", width: 120 },
                    { dataField: "product", headerText: "Product", width: 150 },
                    { dataField: "amount", headerText: "Sale Amount", width: 150, formatter: "$0,###.00"  }
                ]
            }, {
                    name: "Aggregation",
                    rowHeaderVisible: false,
                    selectionBackColor: 'yellow'
               }
            ]
        };
    }

    ngAfterViewInit() {
        var self = this;

        // workbook object is available now.
        var workbook = self.spread.workbook;

        // More init ...
        var sheet = workbook.sheets[1];
        sheet.setRowCount(20, 3);
        sheet.setColumnCount(10, 3);

        sheet.setValue(0, 1, "Total:");
        sheet.setFormula(1, 1, "sum(Sales!D:D)");

        workbook.bind("CellClick", function (s, e) {
            self.message = s.type + "\n" + JSON.stringify({ sheet: e.sheet.name(), row: e.row, column: e.col, sheetArea: e.sheetArea }, null, 4);
        });

        workbook.bind("TopRowChanged", function (s, e) {
            self.message = s.type + "\n" + JSON.stringify({ sheet: e.sheet.name(), oldTopRow: e.oldTopRow, newTopRow: e.newTopRow }, null, 4);
        });
    }
} 